@@ -529,7 +529,7 @@ function template_edit() {
 			$form_array[$field_name]['sub_checkbox'] = array(
 				'name' => 't_' . $field_name,
 				'friendly_name' => __('Use Per-Data Source Value (Ignore this Value)'),
-				'value' => (isset($template_data{'t_' . $field_name}) ? $template_data{'t_' . $field_name} : '')
+				'value' => (isset($template_data['t_' . $field_name]) ? $template_data['t_' . $field_name] : '')
 			);
 		}
 
@@ -603,7 +603,7 @@ function template_edit() {
 		$form_array[$field_name]['sub_checkbox'] = array(
 			'name' => 't_' . $field_name,
 			'friendly_name' => __('Use Per-Data Source Value (Ignore this Value)'),
-			'value' => (isset($template_rrd) ? $template_rrd{'t_' . $field_name} : '')
+			'value' => (isset($template_rrd) ? $template_rrd['t_' . $field_name] : '')
 		);
 	}
 
